# PySentry - pip-audit Benchmark Report

**Generated:** 2025-12-28 13:52:45
**Duration:** 1m 35.02s
**Total Tests:** 20

## Executive Summary

**Overall Success Rate:** 100.0% (20/20 successful runs)

### Small_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.327s) - 23.18x faster than slowest
- **Memory Efficient:** pysentry-osv (10.55 MB) - 7.77x less memory than highest

### Small_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.182s) - 38.04x faster than slowest
- **Memory Efficient:** pysentry-pypi (7.86 MB) - 11.07x less memory than highest

### Large_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.911s) - 15.89x faster than slowest
- **Memory Efficient:** pysentry-osv (10.67 MB) - 8.79x less memory than highest

### Large_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.641s) - 21.06x faster than slowest
- **Memory Efficient:** pysentry-osv (9.44 MB) - 10.05x less memory than highest

## Test Environment

- **Platform:** Linux-6.11.0-1018-azure-x86_64-with-glibc2.39
- **Python Version:** 3.11.14
- **CPU Cores:** 4
- **Total Memory:** 15.62 GB
- **Available Memory:** 14.61 GB

## Performance Comparison

### Small_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.327s | 1.00x |
| 🥈 pysentry-osv | 0.750s | 2.29x |
|  pysentry-all-sources | 1.158s | 3.54x |
|  pysentry-pypa | 1.287s | 3.93x |
|  pip-audit-default | 7.584s | 23.18x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 10.55 MB | 1.00x |
| 🥈 pysentry-pypi | 12.22 MB | 1.16x |
|  pip-audit-default | 46.05 MB | 4.37x |
|  pysentry-pypa | 60.47 MB | 5.73x |
|  pysentry-all-sources | 81.94 MB | 7.77x |

### Small_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.182s | 1.00x |
| 🥈 pysentry-osv | 0.516s | 2.84x |
|  pysentry-all-sources | 0.874s | 4.80x |
|  pysentry-pypa | 0.943s | 5.18x |
|  pip-audit-default | 6.923s | 38.04x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 7.86 MB | 1.00x |
| 🥈 pysentry-osv | 9.61 MB | 1.22x |
|  pip-audit-default | 45.31 MB | 5.76x |
|  pysentry-pypa | 57.05 MB | 7.26x |
|  pysentry-all-sources | 87.06 MB | 11.07x |

### Large_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.911s | 1.00x |
| 🥈 pysentry-pypa | 1.597s | 1.75x |
|  pysentry-osv | 2.036s | 2.24x |
|  pysentry-all-sources | 2.591s | 2.84x |
|  pip-audit-default | 14.470s | 15.89x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 10.67 MB | 1.00x |
| 🥈 pysentry-pypi | 12.83 MB | 1.20x |
|  pip-audit-default | 48.30 MB | 4.53x |
|  pysentry-pypa | 60.53 MB | 5.67x |
|  pysentry-all-sources | 93.79 MB | 8.79x |

### Large_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.641s | 1.00x |
| 🥈 pysentry-pypa | 1.232s | 1.92x |
|  pysentry-osv | 1.967s | 3.07x |
|  pysentry-all-sources | 2.523s | 3.93x |
|  pip-audit-default | 13.505s | 21.06x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 9.44 MB | 1.00x |
| 🥈 pysentry-pypi | 9.65 MB | 1.02x |
|  pip-audit-default | 47.71 MB | 5.06x |
|  pysentry-pypa | 60.27 MB | 6.39x |
|  pysentry-all-sources | 94.88 MB | 10.05x |

## Detailed Analysis

### Pysentry Performance

- **Execution Time:** Avg: 1.221s, Min: 0.182s, Max: 2.591s

- **Memory Usage:** Avg: 42.43 MB, Min: 7.86 MB, Max: 94.88 MB

- **Success Rate:** 100.0% (16/16)

### Pip-Audit Performance

- **Execution Time:** Avg: 10.621s, Min: 6.923s, Max: 14.470s

- **Memory Usage:** Avg: 46.84 MB, Min: 45.31 MB, Max: 48.30 MB

- **Success Rate:** 100.0% (4/4)